
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.tutorial.slots.slots import SlotsUI

web.site_root = SlotsUI
